Learn R Programming

lmem.qtler (version 0.1.1)

pq.diagnostics: Performs phenotypic data quality diagnostics.

Description

Performs phenotypic data quality diagnostic of an object of class cross created by the qtl.cross function, including summary descriptive diagnostics, correlation across traits,and distribution of traits.

Usage

pq.diagnostics (crossobj, boxplot = TRUE, qqplot = FALSE, scatterplot = TRUE,heatplot = TRUE)

Arguments

crossobj
An object of class = cross obtained from the qtl.cross function from this package, or the read.cross function from r/qtl package (Broman and Sen, 2009). This file contains phenotypic means, genotypic marker score, and genetic map.
boxplot
Indicates whether a boxplot should be performed. TRUE/FALSE term. TRUE is set as default.
qqplot
Indicates whether a qqplot should be performed. TRUE/FALSE term. FALSE is set as default.
scatterplot
Indicates whether a scatterplot should be performed. TRUE/FALSE term. TRUE is set as default.
heatplot
Indicates whether a phenotypic heatplot should be performed. TRUE is set as default.

Value

It returns: Boxplot, Scatterplot, QQplot, Heatplot

Details

Performs reports in the work directory.

References

Broman KW, Sen S (2009) A Guide to QTL Mapping with R/qtl. Springer, NewYork. Comadran J, Thomas W, van Eeuwijk F, Ceccarelli S, Grando S, Stanca A, Pecchioni N, Akar T, Al-Yassin A, Benbelkacem A, Ouabbou H, Bort J, Romagosa I, Hackett C, Russell J (2009) Patterns of genetic diversity and linkage disequilibrium in a highly structured Hordeum vulgare association-mapping population for the Mediterranean basin. Theor Appl Genet 119:175-187 Milne et al., (2010) Flapjack - graphical genotype visualization. Bioinformatics 26(24), 3133-3134.

See Also

qtl.cross

Examples

Run this code
## Not run: 
# data (SxM_geno)
# data (SxM_map)
# data (SxM_pheno)
# 
# P.data <- SxM_pheno
# G.data <- SxM_geno
# map.data <- SxM_map
# 
# cross.data <- qtl.cross (P.data, G.data, map.data,
# cross='dh', heterozygotes = FALSE)
# 
# summary (cross.data)
# jittermap (cross.data)
# 
# Pheno Quality
# pq.diagnostics (crossobj=cross.data)
# ## End(Not run)

Run the code above in your browser using DataLab