Arguments
P.data
Name of the file containing phenotypic information.
Each row represents the individuals while each column represents
the phenotypic traits. The first column should be labeled as 'genotype'
and should contain identification name for each individual.
The name of each trait should also be included.
G.data
Name of the file containing genotypic (marker scores)
information. Each row represents the individuals
while each column represents the markers. Headers for markers should be
included, but not for genotypes.
The first column contains the names of the genotypes.
The first row contains the names of the markers.
The marker genotypes are coded by two characters corresponding
to the alleles using a separator between alleles (by default a slash /).
If a single character is given, the genotype is assumed to be homozygous.
Missing values are indicated by default with '-'.
In the example below, the two alleles have been called 1 and 2 because it
is useful to link alleles to their origin, i.e. parent 1 or parent 2.
Therefore, 1 corresponds to homozygous for allele 1 (synonymous to 1/1),
1/2 corresponds to heterozygous, and 2 corresponds to homozygous
for allele 2 (synonymous to 2/2).
In the case of partially informative markers (e.g. dominant markers)
genotypes are coded as 1/- or 2/-, depending on whether the dominant
allele originated from parent 1 or parent 2.
map.data
Name of the file containing marker map information
(i.e. linkage group and position within linkage group).
The file is a text tab delimited file. Each row represents markers.
The file consists of three columns.
Column 1 gives the marker names,
column 2 the chromosome on which the marker has been mapped,
and column 3 indicates the position of the marker within the chromosome.
cross
The type of population studied. The type of population studied.
Options are: F2 (f2), doubled haploids (dh), backcross (bc),
recombinant inbred lines from selfing (riself, ri4self, or ri8self
depending on the number of parents used), recombinant inbred lines from
sib-mating (risib, ri4sib, or ri8sib depending on the number of parents
used), segregating F1 cross-pollinated populations (cp),
heterozygotes
It indicates whether there are heterozygotes or
not in the association mapping population. FALSE is set as default.
sep
To define the espace between the data.