DHpop_pheno: Name of the file containing genotypic (marker scores) information.
Description
For this example, a doubled haploid population of 200 individuals was
developed by crossing a short line (parent A), with a tall line (parent B).
The 200 doubled haploid lines were evaluated in a field trial and the plant
height measured in cm (the data is in the file DHpop_pheno).
The population was also genotyped by SNPs, and the data is presented in the
file DHpop_geno
The map location of each of the markers is in the file DHpop_map.
Format
A data frame 200 genotypes and 1 variable.